@@ -17,7 +17,7 @@
   
   finalSelf = [super create: aZone];
   finalSelf->uniformDouble = 
-    [UniformDouble createBegin: aZone];
+    [UniformDoubleDist createBegin: aZone];
   [finalSelf->uniformDouble setGenerator: generator];
   [finalSelf->uniformDouble setDoubleMin: 0.0 setMax: 1.0];
   finalSelf->uniformDouble = 
